@@ -17,6 +17,10 @@ OC.L10N.register(
     "Drafts are saved in:" : "הטיוטות נשמרות תחת:",
     "Sent messages are saved in:" : "ההודעות שנשלחות נשמרות תחת:",
     "Deleted messages are moved in:" : "הודעות שנמחקו מועברות אל:",
+    "Connecting" : "מתבצע חיבור",
+    "Save" : "שמור",
+    "Connect" : "התחברות",
+    "Password required" : "נדרשת ססמה",
     "Auto" : "אוטומטי",
     "Name" : "שם",
     "Mail address" : "כתובת דוא״ל",
@@ -37,10 +41,6 @@ OC.L10N.register(
     "SMTP Port" : "פתחת SMTP",
     "SMTP User" : "משתמש SMTP",
     "SMTP Password" : "ססמת SMTP",
-    "Connecting" : "מתבצע חיבור",
-    "Save" : "שמור",
-    "Connect" : "התחברות",
-    "Password required" : "נדרשת ססמה",
     "Account settings" : "הגדרות חשבון",
     "Aliases" : "כינויים",
     "Signature" : "חתימה",
@@ -62,6 +62,7 @@ OC.L10N.register(
     "Register" : "רישום",
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "לאפשר ליישומן לאסוף נתונים על אופן השימוש שלך. על בסיס המידע הזה, היישומון יתאים את עצמו להעדפות שלך. הנתונים יישמרו מקומית בלבד.",
     "Trusted senders" : "שולחים מהימנים",
+    "About" : "אודות",
     "Keyboard shortcuts" : "קיצורי מקלדת",
     "Compose new message" : "כתיבת הודעה חדשה",
     "Newer message" : "הודעה חדשה יותר",
@@ -73,6 +74,7 @@ OC.L10N.register(
     "Search" : "חיפוש",
     "Send" : "שליחה",
     "Refresh" : "רענון",
+    "Message {id} could not be found" : "לא ניתן למצוא את הודעה {id}",
     "From" : "מאת",
     "Select account" : "בחר חשבון",
     "To" : "אל",
@@ -92,15 +94,17 @@ OC.L10N.register(
     "Request a read receipt" : "בקשת אישור קריאה",
     "Encrypt message with Mailvelope" : "הצפנת הודעה עם Mailvelope",
     "Enter a date" : "נא למלא תאריך",
-    "Message {id} could not be found" : "לא ניתן למצוא את הודעה {id}",
+    "Choose" : "בחר",
     "Choose a file to add as attachment" : "בחירת קובץ להוספה כקובץ מצורף",
     "Choose a file to share as a link" : "נא לבחור קובץ לשיתוף כקישור",
-    "Choose" : "בחר",
     "Confirm" : "אימות",
     "Plain text" : "טקסט פשוט",
     "Rich text" : "טקסט עשיר",
     "No messages in this mailbox" : "אין הודעות בתיבת הדוא״ל הזאת",
     "No messages" : "אין הודעות",
+    "Blind copy recipients only" : "נמענים נסתרים בלבד",
+    "No trash mailbox configured" : "לא הוגדרה תיבת דוא״ל לאשפה",
+    "Could not delete message" : "לא ניתן למחוק הודעה",
     "Draft: " : "טיוטה:",
     "Unfavorite" : "ביטול כמועדף",
     "Favorite" : "סימון כמועדף",
@@ -114,24 +118,21 @@ OC.L10N.register(
     "Back" : "חזרה",
     "Edit as new message" : "עריכה כהודעה חדשה",
     "Create event" : "יצירת אירוע",
-    "Blind copy recipients only" : "נמענים נסתרים בלבד",
-    "No trash mailbox configured" : "לא הוגדרה תיבת דוא״ל לאשפה",
-    "Could not delete message" : "לא ניתן למחוק הודעה",
     "Load more" : "לטעון עוד",
     "_Mark {number} unread_::_Mark {number} unread_" : ["סימון {number} שלא נקראה","סימון {number} שלא נקראו","סימון {number} שלא נקראו"],
     "Report this bug" : "דיווח על התקלה הזו",
+    "Could not create event" : "לא ניתן ליצור אירוע",
     "All day" : "כל היום",
     "Description" : "תיאור",
     "Create" : "יצירה",
-    "Could not create event" : "לא ניתן ליצור אירוע",
     "Select" : "בחירה",
     "Comment" : "הערה",
     "Accept" : "אשר",
     "Decline" : "דחייה",
+    "individual" : "יחיד",
     "domain" : "שם תחום",
     "Remove" : "הסרה",
     "email" : "דוא״ל",
-    "individual" : "יחיד",
     "Itinerary for {type} is not supported yet" : "פירוט המסלול {type} אינו נתמך עדיין",
     "Could not open mailbox" : "לא ניתן לפתוח את תיבת הדואר",
     "Indexing your messages. This can take a bit longer for larger mailboxes." : "ההודעות שלך מסודרות באינדקס. פעולה זו עשויה לארוך זמן מה בתיבות דואר גדולות.",
@@ -140,28 +141,34 @@ OC.L10N.register(
     "Forward" : "העברה",
     "Translate" : "תרגום",
     "View source" : "הצגת המקור",
+    "Unnamed" : "ללא שם",
+    "Embedded message" : "הודעה מוטמעת",
     "Choose a folder to store the attachment in" : "יש לבחור תיקייה לשמירת הקובץ המצורף",
     "Import into calendar" : "ייבוא ליומן",
     "Download attachment" : "הורדת קובץ מצורף",
     "Save to Files" : "שמירה לקבצים",
-    "Unnamed" : "ללא שם",
-    "Embedded message" : "הודעה מוטמעת",
     "Choose a folder to store the attachments in" : "נא לבחור תיקייה לאחסן בה את הקבצים המצורפים",
     "Save all to Files" : "שמירת הכו לקבצים",
     "This message is encrypted with PGP. Install Mailvelope to decrypt it." : "הודעה זו מוצפנת עם PGP. יש להתקין את Mailvelope כדי לפענח אותה.",
     "The images have been blocked to protect your privacy." : "התמונות נחסמו כדי להגן על הפרטיות שלך",
     "Message frame" : "מסגרת הודעה",
     "Move" : "העברה",
+    "Loading …" : "בטעינה",
+    "Not supported by the server" : "לא נתמך על ידי השרת",
+    "Remove account" : "הסרת חשבון",
+    "Remove {email}" : "להסיר את {email}",
     "Quota" : "מכיסה",
     "Add mailbox" : "הוספת תיבת דוא״ל",
     "Saving" : "שמירה",
     "Move down" : "להוריד למטה",
-    "Remove account" : "הסרת חשבון",
-    "Loading …" : "בטעינה",
-    "Not supported by the server" : "לא נתמך על ידי השרת",
-    "Remove {email}" : "להסיר את {email}",
     "Show all mailboxes" : "הצגת כל תיבות הדוא״ל",
     "Collapse mailboxes" : "צמצום תיבות דוא״ל",
+    "_{total} message_::_{total} messages_" : ["הודעה אחת","{total} הודעות","{total} הודעות"],
+    "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["אחת לא נקראה מתוך {total}","{unread} לא נקראו מתוך {total}","{unread} לא נקראו מתוך {total}","{unread} לא נקראו מתוך {total}"],
+    "The mailbox and all messages in it will be deleted." : "תיבת הדוא״ל על כל ההודעות שבה תימחק.",
+    "Delete mailbox" : "מחיקת תיבת דוא״ל",
+    "Delete mailbox {name}" : "מחיקת תיבת הדוא״ל {name}",
+    "An error occurred, unable to rename the mailbox." : "אירעה שגיאה, לא ניתן לשנות את שם תיבת הדוא״ל.",
     "Mark all as read" : "סימון הכול כנקרא",
     "Mark all messages of this mailbox as read" : "סימון כל ההודעות בתיבת הדוא״ל הזו כנקראו",
     "Add submailbox" : "הוספת תת־תיבת דוא״ל",
@@ -169,54 +176,49 @@ OC.L10N.register(
     "Clear cache" : "פינוי מטמון",
     "Clear locally cached data, in case there are issues with synchronization." : "פינוי הנתונים שמאוחסנים מקומית במטמון, במקרה שיש תקלות בסנכרון.",
     "Sync in background" : "סנכרון ברקע",
-    "Delete mailbox" : "מחיקת תיבת דוא״ל",
-    "The mailbox and all messages in it will be deleted." : "תיבת הדוא״ל על כל ההודעות שבה תימחק.",
-    "Delete mailbox {name}" : "מחיקת תיבת הדוא״ל {name}",
-    "An error occurred, unable to rename the mailbox." : "אירעה שגיאה, לא ניתן לשנות את שם תיבת הדוא״ל.",
-    "_{total} message_::_{total} messages_" : ["הודעה אחת","{total} הודעות","{total} הודעות"],
     "New message" : "הודעה חדשה",
+    "Reply" : "תגובה",
     "Error sending your message" : "שליחת ההודעה שלך נכשלה",
     "Retry" : "ניסיון חוזר",
     "Uploading attachments …" : "הקבצים המצורפים מועלים…",
     "Sending …" : "שולח...",
-    "Reply" : "תגובה",
     "Message" : "הודעה",
     "Oh Snap!" : "שוד ושבר!",
     "Copy to clipboard" : "העתקה ללוח הגזירים",
     "Add" : "הוספה",
     "Show less" : "להציג פחות",
     "Show more" : "להציג יותר",
+    "Clear" : "פינוי",
     "Close" : "סגירה",
     "Body" : "גוף",
     "Date" : "תאריך",
     "Tags" : "תגיות",
     "Select tags" : "בחירת תגיות",
-    "Clear" : "פינוי",
     "Custom" : "מותאם אישית",
     "Signature …" : "חתימה…",
     "Save signature" : "שמירת החתימה",
-    "Add tag" : "הוספת תגית",
-    "Saving tag …" : "התגית נשמרת…",
     "Tag already exists" : "תגית כבר קיימת",
     "An error occurred, unable to create the tag." : "אירעה שגיאה, לא ניתן ליצור את התגית.",
-    "Not found" : "לא נמצא",
+    "Add tag" : "הוספת תגית",
+    "Saving tag …" : "התגית נשמרת…",
     "Could not load your message thread" : "לא ניתן לטעון את שרשור ההודעות שלך",
+    "Not found" : "לא נמצא",
     "Reply to sender only" : "להגיב לשולח בלבד",
     "Mark as unread" : "סימון כלא נקרא",
     "Mark as read" : "סימון כנקרא",
     "Message source" : "מקור ההודעה",
-    "No senders are trusted at the moment." : "אין שולחים מהימנים כרגע.",
     "Could not remove trusted sender {sender}" : "לא ניתן להסיר את השולח המאומת {sender}",
-    "(organizer)" : "(מארגן)",
+    "No senders are trusted at the moment." : "אין שולחים מהימנים כרגע.",
     "Untitled event" : "אירוע ללא כותרת",
+    "(organizer)" : "(מארגן)",
     "Import into {calendar}" : "ייבוא לתוך {calendar}",
     "Event imported into {calendar}" : "האירוע ייובא לתוך {calendar}",
+    "Flight {flightNr} from {depAirport} to {arrAirport}" : "טיסה {flightNr} מ{depAirport} אל {arrAirport}",
     "Airplane" : "מטוב",
     "Reservation {id}" : "הזמנה {id}",
-    "Flight {flightNr} from {depAirport} to {arrAirport}" : "טיסה {flightNr} מ{depAirport} אל {arrAirport}",
-    "Train" : "רכבת",
     "{trainNr} from {depStation} to {arrStation}" : "{trainNr} מ־{depStation} אל {arrStation}",
     "Train from {depStation} to {arrStation}" : "רכבת מ־{depStation} אל {arrStation}",
+    "Train" : "רכבת",
     "Actions" : "פעולות",
     "Priority" : "עדיפות",
     "Mail app" : "יישומון דוא״ל",
@@ -266,7 +268,6 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "יש ללחוץ כאן אם לא הועברת אוטומטית בשניות הקרובות.",
     "Redirect" : "הפנייה",
     "The link leads to %s" : "הקישור מוביל אל %s",
-    "Continue to %s" : "ממשיך אל %s",
-    "Unselect" : "ביטול בחירה"
+    "Continue to %s" : "ממשיך אל %s"
 },
 "nplurals=3; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: 2;");
